describe-class: The 'describe' class for object summaries

describe-classR Documentation

The 'describe' class for object summaries

Description

An S4 class that holds a summary data frame and formatting information. It extends the data.frame class and is the return type for the describe() function.

Usage

## S4 method for signature 'describe'
show(object)

Arguments

object

An object of class describe.

Slots

digits

A numeric value indicating the number of digits to display.


rblimp documentation built on May 18, 2026, 9:07 a.m.