| predict,blimp_obj-method | R Documentation |
blimp_objPredicted scores from blimp_obj
## S4 method for signature 'blimp_obj'
predict(object, ...)
object |
A |
... |
Additional arguments (unused) |
A list of data frames, one per imputation, each containing the predicted values and probability columns from the model.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.