rblimp_source: Runs an 'imp' file with Blimp

View source: R/rblimp_source.R

rblimp_sourceR Documentation

Runs an 'imp' file with Blimp

Description

This function runs 'imp' file with Blimp and captures the output only.

Usage

rblimp_source(file, plots = FALSE, output = TRUE, nopowershell = FALSE)

Arguments

file

a character string to the 'imp' file's location

plots

a logical. Setting to TRUE will generate the data required for plotting by Blimp

output

The type of output printed to the console. 'iteration' or logical TRUE is only iteration history, 'none' or logical FALSE suppresses all output to console, and 'all' prints all output to console.

nopowershell

Windows only. Uses cmd.exe with some limited functions (instead of powershell).

Details

Running rblimp_source will also run a check to see if Blimp is up to date. If Blimp is not up to date, it will prompt the user if it would like to update or not. This check will only be performed on the first run in a session and then every ten hours. This behavior can be disabled by setting the check_blimp_update option to FALSE using options, or by setting the R_BLIMP_NO_UPDATE_CHECK environment variable to "true". This check is not performed if R is not being run with an interactive session. See interactive for more information.

Value

a blimp_out object

Examples


# Run blimp script
## Not run: output <- rblimp_source("filepath/to/syntax")


rblimp documentation built on May 18, 2026, 9:07 a.m.