set_blimp: Set Blimp Executable Location

View source: R/detect_blimp.R

set_blimpR Documentation

Set Blimp Executable Location

Description

This function can set the Blimp executable location if it cannot be autodetected.

Usage

set_blimp(exec, beta = FALSE)

Arguments

exec

a character string for the Blimp executable's location

beta

a logical value. If true rblimp will use the beta version which must be installed

Details

By default rblimp tries to determine the location of Blimp's computational engine based on standard operating system installation locations. This function is useful for non standard installations or when wanting to use a beta version of blimp's computational engine (which must be installed via the updater).

Value

TRUE if the executable is successfully set; otherwise, it produces an error.

Examples


# example code
# Use blimp executable at `filepath` location
## Not run: set_blimp('filepath')

# Use default blimp location but beta build
set_blimp(beta = TRUE)


rblimp documentation built on May 18, 2026, 9:07 a.m.