update_blimp: Update the installed Blimp engine

View source: R/update_blimp.R

update_blimpR Documentation

Update the installed Blimp engine

Description

If Blimp was installed via install_blimp, the latest version is re-downloaded into the managed directory. If Blimp was installed via the system installer, the Blimp Updater application is launched (back-compat).

Usage

update_blimp()

Details

If the session is not interactive, the updater is not opened.

For managed installs, the manifest is checked first and the engine is re-downloaded only if a newer version exists.

Value

Logical indicating whether an update was started.

Privacy

Calling update_blimp() on a managed install contacts updates.blimpstats.com over HTTPS to check for a newer version of Blimp, and downloads from it if one is available. Information may be collected as described in the privacy policy.

See privacy policy: https://www.blimpstats.com/privacy.

See Also

install_blimp

Examples


# Update Blimp
## Not run: update_blimp()


rblimp documentation built on May 18, 2026, 9:07 a.m.