| write.blimp | R Documentation |
A function to write out blimp input and output from a model
write.blimp(object, folder = "")
## S4 method for signature 'blimp_syntax'
write.blimp(object, folder = "")
## S4 method for signature 'blimp_out'
write.blimp(object, folder = "")
## S4 method for signature 'blimp_obj'
write.blimp(object, folder = "")
object |
A |
folder |
a location to a folder to write input and output |
No return value, called for its side effect of writing 'Blimp' input and output files to disk.
write.blimp(blimp_syntax): Write blimp_syntax to file
write.blimp(blimp_out): Write blimp_out to file
write.blimp(blimp_obj): Write blimp_obj files to folder
# Generate Data with `rblimp_sim`
mydata <- rblimp_sim(
c(
'f ~ normal(0, 1)',
'x1:x5 ~ normal(f, 1)',
'y ~ normal(10 + 0.3*f, 1 - .3^2)'
),
n = 500,
seed = 19723,
variables = c('y', 'x1:x5')
)
# Fit SEM Model
model <- rblimp(
list(
structure = 'y ~ f',
measurement = 'f -> x1:x5'
),
mydata,
seed = 3927,
latent = ~ f
)
# Write out input and output
## Not run:
write.blimp(model, "folder_location")
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.