| describe | R Documentation |
describe provides a flexible summary of various R objects,
such as data frames or Blimp model objects. It is an
alternative to summary and is inspired by precis from the rethinking package.
describe(
object,
depth = 1,
pars,
prob = 0.95,
digits = 2,
sort = NULL,
decreasing = FALSE,
...
)
## S4 method for signature 'data.frame'
describe(
object,
depth = 1,
pars,
prob = 0.5,
digits = 2,
sort = NULL,
decreasing = FALSE,
hist = TRUE,
...
)
## S4 method for signature 'blimp_obj'
describe(
object,
depth = 1,
pars,
prob = 0.95,
digits = 2,
sort = NULL,
decreasing = FALSE,
hist = TRUE,
...
)
object |
The object to describe. |
depth |
An integer ( |
pars |
An optional character vector of parameter names to include in the summary. |
prob |
The probability mass for the credible interval (e.g., quantile interval). |
digits |
The number of decimal places to display in the output. |
sort |
An optional character string specifying a column name to sort the results by. |
decreasing |
Logical. If |
... |
Additional arguments passed to specific methods. |
hist |
Logical. If |
An object of class describe, which is a data frame containing summary statistics and attributes for printing.
The data.frame method is adapted from Richard McElreath's precis
function in the rethinking package (https://github.com/rmcelreath/rethinking).
The histospark function is by Hadley Wickham (GPL-3).
The blimp_obj method was written for this package.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.