| describe-class | R Documentation |
An S4 class that holds a summary data frame and formatting
information. It extends the data.frame class and is the return type for
the describe() function.
## S4 method for signature 'describe'
show(object)
object |
An object of class |
digitsA numeric value indicating the number of digits to display.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.