| detect_blimp | R Documentation |
This function is called when running Blimp and can be used to determine what location
rblimp uses for the Blimp executable.
detect_blimp(prompt = TRUE)
prompt |
Logical; when |
rblimp resolves Blimp's executable location in this order:
Any location previously set via set_blimp.
The R_BLIMP environment variable.
A managed install created by install_blimp.
The default operating-system install location of the Blimp system installer.
If none are found and the R session is interactive, detect_blimp
offers to download and install Blimp via install_blimp (unless
prompt = FALSE).
A character string of blimp's executable location.
set_blimp to set blimp location, install_blimp
to install Blimp into a managed directory.
# Obtain blimp location
detect_blimp()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.