| jn_plot | R Documentation |
rblimpGenerates a Johnson-Neyman Plot based on the posterior summaries from the output of rblimp.
jn_plot(formula, model, ci = 0.95, ...)
formula |
an object of class |
model |
an |
ci |
a value between 0 and 1 specifying the credible interval size |
... |
passed bounds search algorithm. See |
To change colors use ggplot2's scale system. Both fill and color are used. See
ggplot2::aes_colour_fill_alpha for more information about setting a manual set of colors.
a ggplot2::ggplot plot. The bounding values are saved in the attribute 'bounds'.
jn_plot_func()
# Generate Data
mydata <- rblimp_sim(
c(
'x ~ normal(0, 1)',
'm ~ normal(0, 1)',
'y ~ normal(10 + 0.5*x + m + 0.2*x*m, 1)'
),
n = 100,
seed = 981273
)
# Run Rblimp
m1 <- rblimp(
'y ~ x m x*m',
mydata,
center = ~ m,
simple = 'x | m',
seed = 10972,
burn = 1000,
iter = 1000
)
# Generate Plot
jn_plot(y ~ x | m, m1)
# Generate Plot with different colors
(
jn_plot(y ~ x | m, m1)
+ ggplot2::scale_fill_manual(
values = c(`FALSE` = '#ca0020', `TRUE` = '#0571b0')
)
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.