View source: R/rblimp_source.R
| rblimp_source | R Documentation |
This function runs 'imp' file with Blimp and captures the output only.
rblimp_source(file, plots = FALSE, output = TRUE, nopowershell = FALSE)
file |
a character string to the 'imp' file's location |
plots |
a logical. Setting to |
output |
The type of output printed to the console.
|
nopowershell |
Windows only. Uses cmd.exe with some limited functions (instead of powershell). |
Running rblimp_source will also run a check to see if Blimp is up to date.
If Blimp is not up to date, it will prompt the user if it would like to update or not.
This check will only be performed on the first run in a session and then every ten hours.
This behavior can be disabled by setting the check_blimp_update option to FALSE using options,
or by setting the R_BLIMP_NO_UPDATE_CHECK environment variable to "true".
This check is not performed if R is not being run with an interactive session. See interactive for more information.
a blimp_out object
# Run blimp script
## Not run: output <- rblimp_source("filepath/to/syntax")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.