| set_blimp | R Documentation |
This function can set the Blimp executable location if it cannot be autodetected.
set_blimp(exec, beta = FALSE)
exec |
a character string for the Blimp executable's location |
beta |
a logical value. If true |
By default rblimp tries to determine the location of Blimp's computational engine based on
standard operating system installation locations. This function is useful for non standard installations
or when wanting to use a beta version of blimp's computational engine (which must be installed via the updater).
TRUE if the executable is successfully set; otherwise, it produces an error.
# example code
# Use blimp executable at `filepath` location
## Not run: set_blimp('filepath')
# Use default blimp location but beta build
set_blimp(beta = TRUE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.