| update_blimp | R Documentation |
If Blimp was installed via install_blimp, the latest version is
re-downloaded into the managed directory. If Blimp was installed via the
system installer, the Blimp Updater application is launched (back-compat).
update_blimp()
If the session is not interactive, the updater is not opened.
For managed installs, the manifest is checked first and the engine is re-downloaded only if a newer version exists.
Logical indicating whether an update was started.
Calling update_blimp() on a managed install contacts
updates.blimpstats.com over HTTPS to check for a newer version of
Blimp, and downloads from it if one is available. Information may be
collected as described in the privacy policy.
See privacy policy: https://www.blimpstats.com/privacy.
install_blimp
# Update Blimp
## Not run: update_blimp()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.